Set KRADLE_API_URL to your Kradle API URL in your .env file.

```
KRADLE_API_URL=https://localhost:3000
KRADLE_API_URL=https://dev.kradle.ai
KRADLE_API_URL=https://staging.kradle.ai
KRADLE_API_URL=https://app.kradle.ai

```
